#
# spec file for package python-Wand
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}

Name:           python-Wand
Version:        0.6.13
Release:        1.3
Summary:        Ctypes-based simple MagickWand API binding for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/emcconville/wand
Source:         https://files.pythonhosted.org/packages/source/W/Wand/Wand-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
Requires:       ImageMagick
BuildRequires:  ImageMagick-devel
BuildRequires:  fdupes
BuildRequires:  fftw3-devel
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module psutil >= 1.0.1}
BuildRequires:  %{python_module pytest >= 7.2.0}
BuildRequires:  %{python_module numpy if (%python-base without python36-base)}
# /SECTION
%python_subpackages

%description
Ctypes-based simple MagickWand API binding for Python.

%prep
%setup -q -n Wand-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Our ImageMagick is build without support of fftw library
# see identify -version and gh#emcconville/wand#476
export PYTEST_ADDOPTS="--skip-fft"
# Three tests failing with
# wand.exceptions.PolicyError: attempt to perform an operation not allowed by the security policy `PDF'
# due to https://build.opensuse.org/package/view_file/graphics/ImageMagick/ImageMagick-configuration-SUSE.patch
%pytest -rs -k 'not (test_resolution_set_03 or test_resolution_set_04 or test_read_with_colorspace or test_histogram)'

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/wand
%{python_sitelib}/Wand-%{version}*-info

%changelog
* Fri Dec 15 2023 Dirk Müller <dmueller@suse.com>
- update to 0.6.13:
  * Removed broken `pyproject.toml` file from source
    distribution.
  * Fixed behavior when passing zero to :meth:`Image.chop()
    <wand.image.BaseImage.chop>`.
  * Fixed `libmagick` yield `MagickCore` library on Linux.
  * Fixed removing mask when passing :const:`None` to
    :meth:`Image.write_mask() <wand.image.BaseImage.write_mask>`
    method. [:issue:`636`]
  * Added new :const:`COMPOSITE_OPERATORS
    <wand.image.COMPOSITE_OPERATORS>` operators.
  * [DOC] Updated Sphinx version to 7.2.6
* Thu Aug  3 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} to select python versions
* Fri Jan 27 2023 Daniel Garcia <daniel.garcia@suse.com>
- Disable broken test in i586, test_histogram
- Update to 0.6.11
  * Fixed format issue when calling Image.convert(), and Image.make_blob()
    methods. [#594]
  * Fixed storage type size for “long” & “quantum” values in
    Image.export_pixels() and Image.import_pixels() methods. [#596]
  * Added filter parameter to Image.distort() method.
  * [TEST] Added Python 3.11 to regression tests for github actions.
  * [TEST] Replaced py.path fixtures with pythlib. [!607 & #608 by Louis
    Sautier]
  * [TEST] Retired Python2 support from regression testing.
  * [TEST] Upgraded Travis CI <https://travis-ci.org/github/emcconville/wand>
    build environments.
* Mon Aug 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to  0.6.10
  * Fixed segmentation fault during resource allocation on M1 processor. [:issue:`587`]
  * Fixed additional segmentation faults introduced with ImageMagick 7.1.0-45.
    [:issue:`587` & :issue:`586`]
- Update to 0.6.9
  * Updated :meth:`Image.fx() <wand.image.BaseImage.fx>` method to raise
    :class:`~wand.exceptions.WandRuntimeError` if ImageMagick is unable to generate
    an image. [:issue:`582`]
  * Fixed :meth:`Image.from_array() <wand.image.Image.from_array>` classmethod to handle
    Numpy's strided arrays. [:issue:`582`]
  * Fixed segmentation fault introduced with ImageMagick 7.1.0-45. [:issue:`586`]
* Mon Aug 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.6.8
  * Added :meth:`Image.label() <wand.image.BaseImage.label>` method.
  * Added :meth:`Image.region() <wand.image.BaseImage.region>` method.
  * Updated :meth:`Image.chop() <wand.image.BaseImage.chop>` method to support gravity keyword.
  * Updated :meth:`Image.extent() <wand.image.BaseImage.extent>` method to support gravity
    keyword. [:issue:`554`]
  * Added .so.9 shared library suffix to :meth:`wand.api.library_paths()` generator when
    searching :const:`MAGICK_HOME` path.
  * Added :const:`QUANTUM_SCALE <wand.version.QUANTUM_SCALE>` constant.
  * Added :meth:`Image.montage() <wand.image.Image.montage>` method. [:issue:`575`]
  * Added :meth:`Image.roll() <wand.image.BaseImage.roll>` method.
  * Fixed returned values for :meth:`Image.connected_components()
    <wand.image.BaseImage.connected_components>` method for ImageMagick 7.1.1. [:issue:`574`]
  * Fixed :c:func:`MagickSetImageDepth()` C-API method signature. [:issue:`577` by Pavel Borzenkov]
  * Fixed :meth:`Image.encipher() <wand.image.BaseImage.encipher>` method to call the
    correct API. [:issue:`578` by Pavel Borzenkov]
  * [DOC] Improved :class:`~wand.drawing.FontMetrics` documentation. [:issue:`566`]
  * [TEST] Migrated CI from travis-ci.org to travis-ci.com.
  * [TEST] Removed unneeded SVG dependency from regression test.
  * [TEST] Suppressed :class:`~wand.exceptions.OptionWarning` when testing user errors.
  * [TEST] Added Python 3.9 regression test for travis-ci.com.
  * [TEST] Removed Python 3.7 & 3.8 regression test for travis-ci.com.
  * [TEST] Added Python 3.10 regression tests for github actions.
* Tue Aug 31 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.6.7
  * Added :meth:`Image.image_add() <wand.image.Image.image_add>` method.
  * Added :meth:`Image.image_get() <wand.image.Image.image_get>` method.
  * Added :meth:`Image.image_remove() <wand.image.Image.image_remove>` method.
  * Added :meth:`Image.image_set() <wand.image.Image.image_set>` method.
  * Added :meth:`Image.image_swap() <wand.image.Image.image_swap>` method.
  * Fixed sub-image extraction on read. [:issue:`532`]
  * Fixed :attr:`~wand.image.BaseImage.background_color` attribute
    when image was not read.
  * [DOC] Completed :doc:`Distortion <./guide/distortion>` guide. [:issue:`534`]
  * [DOC] Added :doc:`Morphology <./guide/morphology>` guide.
* Sat May  8 2021 Matej Cepl <mcepl@suse.com>
- Skip tests using fftw library, we don't have the support built
  in ImageMagick (see gh#emcconville/wand#476).
* Fri May  7 2021 Benjamin Greiner <code@bnavigator.de>
- Fix numpy test BuildRequires for flavors beyond python38
* Mon Mar  1 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v0.6.6
* Mon Feb  8 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v0.6.5
* Sun Jun  7 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v0.6.1
* Tue Mar 31 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.5.9
